==> gatling-http-1.3.4-sources.jar: com/excilys/ebi/gatling/http/request/builder/PostHttpRequestBuilder.scala <==
/**
 * Copyright 2011-2012 eBusiness Information, Groupe Excilys (www.excilys.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.excilys.ebi.gatling.http.request.builder

import com.excilys.ebi.gatling.core.session.EvaluatableString
import com.excilys.ebi.gatling.http.request.HttpRequestBody

object PostHttpRequestBuilder {

	def apply(requestName: String, url: EvaluatableString) = new PostHttpRequestBuilder(HttpAttributes(requestName, "POST", url, Nil, Map.empty, None, Nil), None, HttpParamsAttributes(Nil, Nil))
}

/**
 * This class defines an HTTP request with word POST in the DSL
 */
class PostHttpRequestBuilder(
	httpAttributes: HttpAttributes,
	body: Option[HttpRequestBody],
	paramsAttributes: HttpParamsAttributes)
		extends AbstractHttpRequestWithBodyAndParamsBuilder[PostHttpRequestBuilder](httpAttributes, body, paramsAttributes) {

	private[http] def newInstance(
		httpAttributes: HttpAttributes,
		body: Option[HttpRequestBody],
		paramsAttributes: HttpParamsAttributes) = new PostHttpRequestBuilder(httpAttributes, body, paramsAttributes)
}

==> gatling-http-1.5.2-sources.jar: com/excilys/ebi/gatling/http/request/builder/PostHttpRequestBuilder.scala <==
/**
 * Copyright 2011-2013 eBusiness Information, Groupe Excilys (www.ebusinessinformation.fr)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * 		http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.excilys.ebi.gatling.http.request.builder

import com.excilys.ebi.gatling.core.session.EvaluatableString
import com.excilys.ebi.gatling.http.request.HttpRequestBody

object PostHttpRequestBuilder {

	def apply(requestName: EvaluatableString, url: EvaluatableString) = new PostHttpRequestBuilder(HttpAttributes(requestName, "POST", url, Nil, Map.empty, None, None, Nil), None, HttpParamsAttributes(Nil, Nil))
}

/**
 * This class defines an HTTP request with word POST in the DSL
 */
class PostHttpRequestBuilder(
	httpAttributes: HttpAttributes,
	body: Option[HttpRequestBody],
	paramsAttributes: HttpParamsAttributes)
		extends AbstractHttpRequestWithBodyAndParamsBuilder[PostHttpRequestBuilder](httpAttributes, body, paramsAttributes) {

	private[http] def newInstance(
		httpAttributes: HttpAttributes,
		body: Option[HttpRequestBody],
		paramsAttributes: HttpParamsAttributes) = new PostHttpRequestBuilder(httpAttributes, body, paramsAttributes)
}
